@@ -19,6 +19,7 @@ from global_chem_extensions.analysis_tools.node_pca_analysis.node_pca_analysis i
 
 # Adapters
 
+from global_chem_extensions.software_adapters.smarts_visualizer import SmartsVisualizer
 from global_chem_extensions.software_adapters.pdf_adapter.molpdf_parser import MolPDFAdapter
 from global_chem_extensions.software_adapters.networkx_adapter.networkx_adapter import NetworkxAdapter
 from global_chem_extensions.software_adapters.dimorphite_dl_adapter.dimorphite_dl import DimorphiteAdapter
@@ -469,8 +470,25 @@ class GlobalChemExtensions(object):
         '''
 
         cgenff_molecule = CGenFFMolecule(
-            stream_files=stream_file
+            stream_file=stream_file
         )
 
         return cgenff_molecule
 
+
+    @staticmethod
+    def visualize_smarts(smarts):
+
+        '''
+
+        Arguments:
+            smarts (String): Viusalize the SMARTS string
+
+        '''
+
+        visualizer = SmartsVisualizer(
+            smarts
+        )
+
+        visualizer.get_image()
+
